@@ -222,15 +222,24 @@ bool NRTrackExprScanner::begin(const vector<string> &track_exprs, ValType valtyp
         }
 	}
 
-    if (isNull(filter) && (typeid(m_itr.itr()) == typeid(EMRBeatIterator) || typeid(m_itr.itr()) == typeid(EMRBeatExtIterator)) &&
-        g_naryn->beat_itr_warning_size() != (uint64_t)-1 && m_itr.itr().size() > g_naryn->beat_itr_warning_size())
-    {
-        if (typeid(m_itr.itr()) == typeid(EMRBeatIterator))
-            vwarning("The Beat Iterator is going to produce %llu points.\n"
-                     "To improve performance please consider using a filter.\n", m_itr.itr().size());
-        else
-            vwarning("The Extended Beat Iterator might produce up to %llu points.\n"
-                     "To improve performance please consider using a filter.\n", m_itr.itr().size());
+    if (isNull(filter)){
+        const EMRTrackExpressionIterator &itr = m_itr.itr();
+        if ((typeid(itr) == typeid(EMRBeatIterator) ||
+             typeid(itr) == typeid(EMRBeatExtIterator)) &&
+            g_naryn->beat_itr_warning_size() != (uint64_t)-1 &&
+            itr.size() > g_naryn->beat_itr_warning_size()) {
+          if (typeid(itr) == typeid(EMRBeatIterator)) {
+            vwarning(
+                "The Beat Iterator is going to produce %llu points.\n"
+                "To improve performance please consider using a filter.\n",
+                itr.size());
+          } else {
+            vwarning(
+                "The Extended Beat Iterator might produce up to %llu points.\n"
+                "To improve performance please consider using a filter.\n",
+                itr.size());
+          }
+        }
     }
 
 	m_num_evals = 0;
